pub struct TrackedData { /* private fields */ }Expand description
Cache for all the tracked data of an entity. Used for the
SetEntityDataS2c packet.
Implementations
Sourceimpl TrackedData
impl TrackedData
Sourcepub fn init_data(&self) -> Option<&[u8]>
pub fn init_data(&self) -> Option<&[u8]>
Returns initial tracked data for the entity, ready to be sent in the
SetEntityDataS2c packet. This is used when the entity
enters the view of a client.
Sourcepub fn update_data(&self) -> Option<&[u8]>
pub fn update_data(&self) -> Option<&[u8]>
Contains updated tracked data for the entity, ready to be sent in the
SetEntityDataS2c packet. This is used when tracked
data is changed and the client is already in view of the entity.
pub fn insert_init_value<V: Encode>(&mut self, index: u8, type_id: u8, value: V)
pub fn remove_init_value(&mut self, index: u8) -> bool
pub fn append_update_value<V: Encode>( &mut self, index: u8, type_id: u8, value: V, )
pub fn clear_update_values(&mut self)